@@ -80,7 +80,9 @@ class Name(object):
 
     load.lock = Lock()
 
-    def fake(self, length=None):
+    def fake(self, surname=None, length=None):
+        if not surname:
+            surname = self.surname
         if length:
-            return random.choice(self.surname) + "".join(random.choices(self.name, k=length))
-        return random.choice(self.surname) + "".join(random.choices(self.name, k=random.choice([1, 2])))
+            return random.choice(surname) + "".join(random.choices(self.name, k=length))
+        return random.choice(surname) + "".join(random.choices(self.name, k=random.choice([1, 2])))
